// When color definition differs for dark and light variant,
// it gets @if ed depending on $variant

$base_color: if($variant =='light', #ffffff, #404040);
$text_color: if($variant == 'light', #202020, #D3D3D3);
$bg_color: if($variant =='light', #F0F0F0, #2f2f2f);
$fg_color: if($variant =='light', #202020, #f0f0f0);

$selected_fg_color: #ffffff;
$selected_bg_color: if($variant == 'light', #92b372, #92b372);

$borders_color: if($variant =='light', darken($bg_color,9%), darken($bg_color,6%));

$separator_color: if($variant == 'light', #cfcfcf, darken($bg_color, 6%));

$link_color: if($variant == 'light', darken($selected_bg_color,10%),
                                     lighten($selected_bg_color,20%));

$warning_color: #F27835;
$error_color: #FC4138;
$destructive_color: #F04A50;

$insensitive_fg_color: if($variant == 'light', transparentize($fg_color, 0.45), transparentize($fg_color, 0.55));

$tooltip_bg_color: #fbeaa0;
$tooltip_fg_color: #4a4a4a;
$tooltip_border_color: #d0d0d0;

$osd_fg_color: #c3c3c3;
$osd_bg_color: #353535;

$osd_button_bg: transparentize(lighten($osd_bg_color, 22%), 0.6);
$osd_button_border: transparentize(darken($osd_bg_color, 20%), 0.6);

$osd_entry_bg: transparentize(lighten($osd_bg_color, 22%), 0.6);
$osd_entry_border: transparentize(darken($osd_bg_color, 12%), 0.6);

$osd_insensitive_fg_color: mix($osd_fg_color, opacify($osd_bg_color, 1), 30%);

$panel_bg: #2f2f2f;
$panel_fg: #f0f0f0;

$entry_bg: if($variant=='light', $base_color, lighten($base_color, 0%));
$entry_border: if($variant == 'light', #cfd6e6, darken($borders_color, 0%));

$button_bg: if($variant == 'light', lighten($bg_color, 2%), lighten($base_color, 2%));
$button_border: $entry_border;
