@define-color mint_accent #92b372;
@define-color mint_header #2f2f2f;
@define-color mint_content #383838;
@define-color mint_button_hover #454545;
@define-color mint_button_unfocused #616166;

/* GTK NAMED COLORS ---------------- use responsibly! */
@define-color accent_bg_color @mint_accent;
@define-color accent_fg_color white;
@define-color accent_color @mint_accent;
@define-color destructive_bg_color @red_4;
@define-color destructive_fg_color white;
@define-color destructive_color #ff7b63;
@define-color success_bg_color @green_5;
@define-color success_fg_color white;
@define-color success_color @green_1;
@define-color warning_bg_color #cd9309;
@define-color warning_fg_color rgba(0, 0, 0, 0.8);
@define-color warning_color @yellow_2;
@define-color error_bg_color @red_4;
@define-color error_fg_color white;
@define-color error_color #ff7b63;
@define-color window_bg_color @mint_content;
@define-color window_fg_color white;
@define-color view_bg_color @mint_content;
@define-color view_fg_color white;
@define-color headerbar_bg_color @window_bg_color;
@define-color headerbar_fg_color white;
@define-color headerbar_border_color white;
@define-color headerbar_backdrop_color @window_bg_color;
@define-color headerbar_shade_color rgba(0, 0, 0, 0.36);
@define-color headerbar_darker_shade_color rgba(0, 0, 0, 0.9);
@define-color sidebar_bg_color @mint_header;
@define-color sidebar_fg_color white;
@define-color sidebar_backdrop_color @mint_header;
@define-color sidebar_shade_color rgba(0, 0, 0, 0.25);
@define-color sidebar_border_color rgba(0, 0, 0, 0.36);
@define-color secondary_sidebar_bg_color #2a2a2a;
@define-color secondary_sidebar_fg_color white;
@define-color secondary_sidebar_backdrop_color #272727;
@define-color secondary_sidebar_shade_color rgba(0, 0, 0, 0.25);
@define-color secondary_sidebar_border_color rgba(0, 0, 0, 0.36);
@define-color card_bg_color @mint_content;
@define-color card_fg_color white;
@define-color card_shade_color rgba(0, 0, 0, 0.36);
@define-color dialog_bg_color @mint_content;
@define-color dialog_fg_color white;
@define-color popover_bg_color #383838;
@define-color popover_fg_color white;
@define-color popover_shade_color rgba(0, 0, 0, 0.25);
@define-color thumbnail_bg_color #383838;
@define-color thumbnail_fg_color white;
@define-color shade_color rgba(0, 0, 0, 0.25);
@define-color scrollbar_outline_color rgba(0, 0, 0, 0.5);
