@define-color mint_accent #92b372;
@define-color mint_header #d9d9d9;
@define-color mint_content #f0f0f0;
@define-color mint_button_hover #fafafa;
@define-color mint_button_unfocused #525255;

/* GTK NAMED COLORS ---------------- use responsibly! */
@define-color accent_bg_color @mint_accent;
@define-color accent_fg_color white;
@define-color accent_color @mint_accent;
@define-color destructive_bg_color @red_3;
@define-color destructive_fg_color white;
@define-color destructive_color @red_4;
@define-color success_bg_color @green_4;
@define-color success_fg_color white;
@define-color success_color #1b8553;
@define-color warning_bg_color @yellow_5;
@define-color warning_fg_color rgba(0, 0, 0, 0.8);
@define-color warning_color #9c6e03;
@define-color error_bg_color @red_3;
@define-color error_fg_color white;
@define-color error_color @red_4;
@define-color window_bg_color @mint_content;
@define-color window_fg_color rgba(0, 0, 0, 0.8);
@define-color view_bg_color @mint_content;
@define-color view_fg_color rgba(0, 0, 0, 0.8);
@define-color headerbar_bg_color @window_bg_color;
@define-color headerbar_fg_color rgba(0, 0, 0, 0.8);
@define-color headerbar_border_color rgba(0, 0, 0, 0.8);
@define-color headerbar_backdrop_color @window_bg_color;
@define-color headerbar_shade_color rgba(0, 0, 0, 0.12);
@define-color headerbar_darker_shade_color rgba(0, 0, 0, 0.12);
@define-color sidebar_bg_color @mint_header;
@define-color sidebar_fg_color rgba(0, 0, 0, 0.8);
@define-color sidebar_backdrop_color @mint_header;
@define-color sidebar_shade_color rgba(0, 0, 0, 0.07);
@define-color sidebar_border_color rgba(0, 0, 0, 0.07);
@define-color secondary_sidebar_bg_color #f3f3f3;
@define-color secondary_sidebar_fg_color rgba(0, 0, 0, 0.8);
@define-color secondary_sidebar_backdrop_color #f6f6f6;
@define-color secondary_sidebar_shade_color rgba(0, 0, 0, 0.07);
@define-color secondary_sidebar_border_color rgba(0, 0, 0, 0.07);
@define-color card_bg_color @mint_content;
@define-color card_fg_color rgba(0, 0, 0, 0.8);
@define-color card_shade_color rgba(0, 0, 0, 0.07);
@define-color dialog_bg_color @mint_content;
@define-color dialog_fg_color rgba(0, 0, 0, 0.8);
@define-color popover_bg_color #ffffff;
@define-color popover_fg_color rgba(0, 0, 0, 0.8);
@define-color popover_shade_color rgba(0, 0, 0, 0.07);
@define-color thumbnail_bg_color #ffffff;
@define-color thumbnail_fg_color rgba(0, 0, 0, 0.8);
@define-color shade_color rgba(0, 0, 0, 0.07);
@define-color scrollbar_outline_color white;
